==> haskell-criterion-1.5.5.0-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.5.0
id: criterion-1.5.5.0-J3F9IQec5TpCZMOIlzGPYL
key: criterion-1.5.5.0-J3F9IQec5TpCZMOIlzGPYL
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: a0bf85f6eb1ecf522331a309715676b5
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.5.0-J3F9IQec5TpCZMOIlzGPYL
depends:
    Glob-0.10.0-Auv1MKJYWeNGOxJrjCEIG4
    aeson-1.4.4.0-KIBRt7ojt2h8yml6gHrkIF
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk binary-0.8.6.0
    bytestring-0.10.8.2 cassava-0.5.1.0-HR6puL5afLO7Mo3abEvCbN
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    criterion-measurement-0.1.1.0-98vhkkDTeZMI6hO9GN2vDr
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk filepath-1.4.2.1
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-GF0wMfAIOCv6jQ9v7CGBV0
    microstache-1.0.1.1-7mdAwYfD0C5CaUGsAPG2jl mtl-2.2.2
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 statistics-0.15.0.0-Be8vKQ7LkVe7vmBrgNcJbH
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.5.5.0-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.5.0
id: criterion-1.5.5.0-FDzq0BUbRK2E0ebch1h23S
key: criterion-1.5.5.0-FDzq0BUbRK2E0ebch1h23S
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: 8bbda96d4913d3ba957e98fcb4f7a912
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.5.0-FDzq0BUbRK2E0ebch1h23S
depends:
    Glob-0.10.0-Auv1MKJYWeNGOxJrjCEIG4
    aeson-1.4.4.0-KIBRt7ojt2h8yml6gHrkIF
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk binary-0.8.6.0
    bytestring-0.10.8.2 cassava-0.5.1.0-49Ewb2e8ZNJ8Q9xXbn9N9i
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    criterion-measurement-0.1.1.0-98vhkkDTeZMI6hO9GN2vDr
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk filepath-1.4.2.1
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-GF0wMfAIOCv6jQ9v7CGBV0
    microstache-1.0.1.1-7mdAwYfD0C5CaUGsAPG2jl mtl-2.2.2
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 statistics-0.15.0.0-Be8vKQ7LkVe7vmBrgNcJbH
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
